@@ -1,5 +1,5 @@
 
-#' Create a \acronym{DSSAT} \acronym{ICASA} File from \acronym{POWER} Data
+#' Create a DSSAT ICASA File from POWER Data
 #'
 #' Get \acronym{POWER} values for a single point or region and create an
 #'   \acronym{ICASA} format text file suitable for use in \acronym{DSSAT} for
@@ -17,13 +17,13 @@
 #'
 #' @details This function is essentially a wrapper for \code{\link{get_power}}
 #'   that queries the \acronym{POWER} \acronym{API} and writes a \acronym{DSSAT}
-#'   \acronym{ICASA} weather file to disk.  All necessary `pars` are
+#'   \acronym{ICASA} weather file to disk.  All necessary \var{pars} are
 #'   automatically included in the query.
 #'
 #'   Further details for each of the arguments are provided in their
 #'   respective sections following below.
 #'
-#' @section Argument details for `lonlat`:
+#' @section Argument details for \var{onlat}:
 #' \describe{
 #'   \item{For a single point}{To get a specific cell, 1/2 x 1/2 degree, supply
 #'   a length-2 numeric vector giving the decimal degree longitude and latitude
@@ -38,11 +38,11 @@
 #'   degrees* of 1/2 x 1/2 degree data, *i.e.*, 100 points maximum in total.}
 #' }
 #'
-#' @section Argument details for `dates`: If `dates` is unspecified, defaults to
-#'   a start date of 1983-01-01 (the earliest available data) and an end date of
-#'   current date according to the system. If one date only is provided, it will
-#'   be treated as both the start date and the end date and only a single day's
-#'   values will be returned.
+#' @section Argument details for \var{dates}: If \var{dates} is unspecified,
+#'   defaults to a start date of 1983-01-01 (the earliest available data) and an
+#'   end date of current date according to the system. If one date only is
+#'   provided, it will be treated as both the start date and the end date and
+#'   only a single day's values will be returned.
 #'
 #' @seealso \code{\link{create_met}} Create an \acronym{APSIM} met File from
 #'   \acronym{NASA} \acronym{POWER} Data
@@ -69,7 +69,7 @@ create_icasa <- function(lonlat,
                          dates,
                          dsn,
                          file_out) {
-  if (missing(dsn) || missing(file_out)) {
+  if (missing(dsn) | missing(file_out)) {
     stop(
       call. = FALSE,
       "You must provide a file location, `dsn` and file name, `file_out`."
@@ -80,14 +80,6 @@ create_icasa <- function(lonlat,
   pars <- c("T2M") # this is a dummy variable to check lonlat values,
   # POWER will automatically select the proper pars for query
 
-  if (!is.numeric(lonlat) && toupper(lonlat) == "GLOBAL") {
-    stop(
-      call. = FALSE,
-      "The `lonlat` must be numeric values. Global coverage is not ",
-      "available for `create_icasa()`"
-    )
-  }
-
   if (substr(file_out, nchar(file_out) - 3, nchar(file_out)) != ".txt") {
     file_out <- paste0(file_out, ".txt")
   }
