@@ -1,22 +1,7 @@
 
 # test queries -----------------------------------------------------------------
-context("Test that create_icasa creates a text file")
-test_that("create_icasa stops if user specifies global coverage", {
-  vcr::use_cassette("create_icasa_global_stop", {
-    expect_error(
-      create_icasa(
-        lonlat = "global",
-        dates = c("1983-01-01"),
-        file_out = "icasa.txt",
-        dsn = tmpdir()
-      ),
-      regexp = "*The `lonlat` must be numeric values.*"
-    )
-  })
-})
-
-
-test_that("create_icasa creates a txt file with proper values", {
+context("Test that create_icasa() creates a text file")
+test_that("create_icasa() creates a txt file with proper values", {
   vcr::use_cassette("create_icasa_file", {
     create_icasa(
       lonlat = c(151.81, -27.48),
@@ -36,7 +21,7 @@ test_that("create_icasa() fails if no dsn or file_out are supplied", {
   expect_error(
     create_icasa(
       lonlat = c(151.81, -27.48),
-      dates = c("1983-01-01"),
+      dates = "1983-01-01",
       dsn = tempdir()
     )
   )
@@ -44,7 +29,7 @@ test_that("create_icasa() fails if no dsn or file_out are supplied", {
   expect_error(
     create_icasa(
       lonlat = c(151.81, -27.48),
-      dates = c("1983-01-01"),
+      dates = "1983-01-01",
       file_out = tempfile()
     )
   )
