@@ -1,6 +1,6 @@
 
 # Date handling and checking ---------------------------------------------------
-context("Check dates function handles dates correctly")
+context("Check dates handles dates correctly")
 test_that("Missing `dates` are properly handled", {
   temporal_average <- "DAILY"
   dates <- NULL
@@ -17,7 +17,7 @@ test_that("`dates` with one value set one day query", {
   expect_equal(dates[2], "19830101")
 })
 
-test_that("`dates` >2 cause an error", {
+test_that("`dates` > 2 cause an error", {
   temporal_average <- "DAILY"
   dates <- c("1983-01-01", "1983-01-02", "1983-01-03")
   lonlat <- c(-179.5, -89.5)
@@ -96,8 +96,8 @@ test_that("Dates are returned as a vector of characters", {
 })
 
 test_that(
-  "If temporal_average == INTERANNUAL and dates are specified, that
-  a message is emitted about years only", {
+  "If temporal_average == INTERANNUAL and dates are specified, that only years
+  are returned", {
     temporal_average <- "INTERANNUAL"
     dates <- c("1983-01-01", "1984-01-01")
     lonlat <- c(-179.5, -89.5)
@@ -116,130 +116,177 @@ test_that("If temporal_average == INTERANNUAL and <2 dates provided, error", {
 })
 
 
+# community checks -------------------------------------------------------------
+context("Test that .check_community() handles community checks correctly")
+test_that(".check_community() properly reports errors", {
+
+  community <- "R"
+  pars <- c(
+    "ALLSKY_SFC_SW_DWN_03_GMT",
+    "ALLSKY_SFC_LW_DWN",
+    "ALLSKY_SFC_SW_DWN_06_GMT",
+    "RH2M"
+  )
+  expect_error(.check_community(community, pars))
+
+  community <- "AG"
+  pars <- "ALLSKY_SFC_SW_DWN_00_GMT"
+  expect_error(.check_community(community, pars))
+}
+)
+
 # lonlat checks ----------------------------------------------------------------
-context("Test that check_lonlat function handles lat lon strings correctly")
-test_that("check_lonlat properly reports errors", {
+context("Test that .check_lonlat() handles lat lon strings correctly")
+test_that(".check_lonlat() properly reports errors", {
   # set up pars argument for testing
   pars <- "T2M"
 
   # out-of-scope latitude for singlePoint
   lonlat <- c(-27.5, 151.5)
-  expect_error(.check_lonlat(lonlat, pars))
+  temporal_average <- "DAILY"
+  expect_error(.check_lonlat(lonlat, pars, temporal_average))
 
   # out-of-scope longitude for singlePoint
   lonlat <- c(0, 181)
-  expect_error(.check_lonlat(lonlat, pars))
+  temporal_average <- "DAILY"
+  expect_error(.check_lonlat(lonlat, pars, temporal_average))
 
   # non-numeric values for singlePoint
   lonlat <- c("x", 181)
-  expect_error(.check_lonlat(lonlat, pars))
+  temporal_average <- "DAILY"
+  expect_error(.check_lonlat(lonlat, pars, temporal_average))
 
   # out-of-scope latitude for regional
   lonlat <- c(-90, 90, -181, 181)
-  expect_error(.check_lonlat(lonlat, pars))
+  temporal_average <- "DAILY"
+  expect_error(.check_lonlat(lonlat, pars, temporal_average))
 
   # out-of-scope longitude for regional
   lonlat <- c(-91, 91, -180, 180)
-  expect_error(.check_lonlat(lonlat, pars))
+  temporal_average <- "DAILY"
+  expect_error(.check_lonlat(lonlat, pars, temporal_average))
 
   # incorrect orders for regional
   lonlat <- c(-91, 91, -180, 180)
-  expect_error(.check_lonlat(lonlat, pars))
+  temporal_average <- "DAILY"
+  expect_error(.check_lonlat(lonlat, pars, temporal_average))
 
   # non-numeric values for regional
   lonlat <- c(112.91972, -55.11694, "x", 159.256088)
-  expect_error(.check_lonlat(lonlat, pars))
+  temporal_average <- "DAILY"
+  expect_error(.check_lonlat(lonlat, pars, temporal_average))
 
   # incorrect order of values requested for regional
   lonlat <- c(-90, 90, 180, -180)
-  expect_error(.check_lonlat(lonlat, pars))
+  temporal_average <- "DAILY"
+  expect_error(.check_lonlat(lonlat, pars, temporal_average))
 
   lonlat <- c(90, -90, -180, 180)
-  expect_error(.check_lonlat(lonlat, pars))
+  temporal_average <- "DAILY"
+  expect_error(.check_lonlat(lonlat, pars, temporal_average))
+
+  # invalid lonlat value
+  lonlat <- "x"
+  temporal_average <- "DAILY"
+  expect_error(.check_lonlat(lonlat, pars, temporal_average))
 })
 
-test_that("check_lonlat stops if more than three are requested for global", {
-  lonlat <- "Global"
-  pars <- c(
-    "T2M",
-    "T2MN",
-    "T2MX",
-    "RH2M",
-    "toa_dwn",
-    "swv_dwn",
-    "lwv_dwn",
-    "DFP2M",
-    "RAIN",
-    "WS10M"
-  )
-  expect_error(.check_lonlat(lonlat, pars))
-})
-
-test_that("check_lonlat handles single point properly", {
-  test <- .check_lonlat(lonlat = c(-179.5, -89.5), pars)
+test_that(".check_lonlat() handles single point properly", {
+  temporal_average <- "DAILY"
+  test <- .check_lonlat(lonlat = c(-179.5, -89.5),
+                        pars,
+                        temporal_average)
   expect_equal(test$lon, -179.5)
   expect_equal(test$lat, -89.5)
   expect_equal(test$identifier, "SinglePoint")
 })
 
-test_that("check_lonlat checks validity of single lon values", {
-  expect_error(.check_lonlat(lonlat = c(179.5, 91), pars),
+test_that(".check_lonlat() checks validity of single lon values", {
+  temporal_average <- "DAILY"
+  expect_error(.check_lonlat(lonlat = c(179.5, 91),
+                             pars,
+                             temporal_average),
     regexp = "\nPlease check your latitude, `91`,*"
   )
 })
 
-test_that("check_lonlat checks validity of single lat values", {
-  expect_error(.check_lonlat(lonlat = c(182, 90), pars),
+test_that(".check_lonlat() checks validity of single lat values", {
+  temporal_average <- "DAILY"
+  expect_error(.check_lonlat(lonlat = c(182, 90),
+                             pars,
+                             temporal_average),
     regexp = "Please check your longitude, `182`,*"
   )
 })
 
 # bbox checks ------------------------------------------------------------------
 
-test_that("check_lonlat handles bboxes that are too large", {
-  expect_error(.check_lonlat(lonlat = c(-179.5, -89.5, 179.5, 89.5), pars),
+test_that(".check_lonlat() handles bboxes that are too large", {
+  temporal_average <- "DAILY"
+  expect_error(.check_lonlat(lonlat = c(-179.5, -89.5, 179.5, 89.5),
+                             pars,
+                             temporal_average),
     regexp = "Please provide correct bounding box values*"
   )
 })
 
-test_that("check_lonlat checks order of the latitude values", {
-  expect_error(.check_lonlat(lonlat = c(-179.5, 89.5, 179.5, -89.5), pars),
+test_that(".check_lonlat() checks order of the latitude values", {
+  temporal_average <- "DAILY"
+  expect_error(.check_lonlat(lonlat = c(-179.5, 89.5, 179.5, -89.5),
+                             pars,
+                             temporal_average),
     regexp = "\nThe first `lat` value must be the minimum value.\n"
   )
 })
 
-test_that("check_lonlat checks order of the longitude values", {
-  expect_error(.check_lonlat(lonlat = c(179.5, -89.5, -179.5, 89.5), pars),
+test_that(".check_lonlat() checks order of the longitude values", {
+  temporal_average <- "DAILY"
+  expect_error(.check_lonlat(lonlat = c(179.5, -89.5, -179.5, 89.5),
+                             pars,
+                             temporal_average),
     regexp = "\nThe first `lon` value must be the minimum value.\n"
   )
 })
 
-test_that("check_lonlat checks validity of bbox latmin values", {
-  expect_error(.check_lonlat(lonlat = c(-179.5, 91, -179.5, 90), pars),
+test_that(".check_lonlat() checks validity of bbox latmin values", {
+  temporal_average <- "DAILY"
+  expect_error(.check_lonlat(lonlat = c(-179.5, 91, -179.5, 90),
+                             pars,
+                             temporal_average),
     regexp = "\nPlease check your latitude, `91`, `90`*"
   )
 })
 
-test_that("check_lonlat checks validity of bbox latmax values", {
-  expect_error(.check_lonlat(lonlat = c(-179.5, 90, -179.5, 93), pars),
+test_that(".check_lonlat() checks validity of bbox latmax values", {
+  temporal_average <- "DAILY"
+  expect_error(.check_lonlat(lonlat = c(-179.5, 90, -179.5, 93),
+                             pars,
+                             temporal_average),
     regexp = "\nPlease check your latitude, `90`, `93`,*"
   )
 })
 
-test_that("check_lonlat checks validity of bbox lonmin values", {
-  expect_error(.check_lonlat(lonlat = c(-181.5, 89.5, -179.5, 89.5), pars),
+test_that(".check_lonlat() checks validity of bbox lonmin values", {
+  temporal_average <- "DAILY"
+  expect_error(.check_lonlat(lonlat = c(-181.5, 89.5, -179.5, 89.5),
+                             pars,
+                             temporal_average),
     regexp = "\nPlease check your longitude, `-181.5`, `-179.5`*"
   )
 })
 
-test_that("check_lonlat checks validity of bbox lonmax values", {
-  expect_error(.check_lonlat(lonlat = c(-179.5, 89.5, 181, 89.5), pars),
+test_that(".check_lonlat() checks validity of bbox lonmax values", {
+  temporal_average <- "DAILY"
+  expect_error(.check_lonlat(lonlat = c(-179.5, 89.5, 181, 89.5),
+                             pars,
+                             temporal_average),
     regexp = "\nPlease check your longitude, `-179.5`, `181`,*"
   )
 })
 
-test_that("check_lonlat returns message with proper identifier when valid
+test_that(".check_lonlat() returns message with proper identifier when valid
           coordinates are given", {
+            temporal_average <- "DAILY"
   test <- .check_lonlat(
     lonlat = c(
       -179.5,
@@ -247,7 +294,8 @@ test_that("check_lonlat returns message with proper identifier when valid
       -179.5,
       89.5
     ),
-    pars
+    pars,
+    temporal_average
   )
   expect_equal(test$bbox, "88.5,-179.5,89.5,-179.5")
   expect_equal(test$identifier, "Regional")
@@ -255,8 +303,8 @@ test_that("check_lonlat returns message with proper identifier when valid
 
 
 # parameter checks -------------------------------------------------------------
-context("Test that check_pars function handles pars strings correctly")
-test_that("check_pars stops if no `par` provided", {
+context("Test that check_pars handles pars strings correctly")
+test_that(".check_pars() stops if no `pars` provided", {
   temporal_average <- "DAILY"
   lonlat <- c(-179.5, -89.5)
 
@@ -267,7 +315,7 @@ test_that("check_pars stops if no `par` provided", {
   ))
 })
 
-test_that("check_pars stops if no `temporal_average` provided", {
+test_that(".check_pars()  stops if no `temporal_average` provided", {
   pars <- "AG"
   lonlat <- c(-179.5, -89.5)
 
@@ -278,7 +326,7 @@ test_that("check_pars stops if no `temporal_average` provided", {
   ))
 })
 
-test_that("check_pars stops if `pars` not valid", {
+test_that(".check_pars()  stops if `pars` not valid", {
   pars <- "asdflkuewr"
   temporal_average <- "DAILY"
   lonlat <- c(-179.5, -89.5)
@@ -290,9 +338,9 @@ test_that("check_pars stops if `pars` not valid", {
   ))
 })
 
-test_that("check_pars stops if `pars` not valid", {
+test_that(".check_pars()  stops if `pars` not valid for given temporal_average", {
   pars <- "ALLSKY_SFC_SW_DWN_03_GMT"
-  temporal_average <- "Interannual"
+  temporal_average <- "INTERANNUAL"
   lonlat <- c(-179.5, -89.5)
 
   expect_error(.check_pars(
@@ -322,28 +370,7 @@ test_that("pars are returned as a comma separated string with no spaces", {
   expect_length(pars, 3)
 })
 
-test_that("`temporal_average` is set to `CLIMATOLOGY` when global data
-          queried", {
-  pars <- c(
-    "ALLSKY_SFC_SW_DWN_03_GMT",
-    "ALLSKY_SFC_LW_DWN"
-  )
-  temporal_average <- "DAILY"
-  lonlat <- "GLOBAL"
-  expect_message(pars <-
-    .check_pars(
-      pars,
-      temporal_average,
-      lonlat
-    ))
-  expect_equal(
-    pars$pars,
-    "ALLSKY_SFC_SW_DWN_03_GMT,ALLSKY_SFC_LW_DWN"
-  )
-  expect_equal(pars$temporal_average, "CLIMATOLOGY")
-})
-
-test_that("Only 3 pars are allowed when temporal_average = <- CLIMATOLOGY", {
+test_that("Only 3 pars are allowed when `temporal_average` = CLIMATOLOGY", {
   pars <- c(
     "ALLSKY_SFC_SW_DWN_03_GMT",
     "ALLSKY_SFC_LW_DWN",
@@ -351,7 +378,7 @@ test_that("Only 3 pars are allowed when temporal_average = <- CLIMATOLOGY", {
     "RH2M"
   )
   temporal_average <- "CLIMATOLOGY"
-  lonlat <- "GLOBAL"
+  lonlat <- NULL
   expect_error(
     pars <-
       .check_pars(pars, temporal_average, lonlat),
@@ -359,7 +386,7 @@ test_that("Only 3 pars are allowed when temporal_average = <- CLIMATOLOGY", {
   )
 })
 
-test_that("Only 20 pars are allowed when temporal_average ! <- CLIMATOLOGY", {
+test_that("Only 20 pars are allowed when `temporal_average` != CLIMATOLOGY", {
   pars <- c(
     "ALLSKY_SFC_LW_DWN",
     "ALLSKY_TOA_SW_DWN",
@@ -393,20 +420,21 @@ test_that("Only 20 pars are allowed when temporal_average ! <- CLIMATOLOGY", {
   )
 })
 
-test_that("Only unique pars are queried", {
+test_that("Only unique `pars` are queried", {
   pars <- c(
     "RH2M",
     "RH2M",
     "RH2M"
   )
   temporal_average <- "CLIMATOLOGY"
-  lonlat <- "GLOBAL"
+  lonlat <- NULL
   pars <- .check_pars(pars, temporal_average, lonlat)
   expect_equal(pars[[1]], "RH2M")
   expect_equal(length(pars[[1]]), 1)
 })
 
-test_that("If an invalid temporal average is given for a par, an error occurs", {
+test_that("If an invalid temporal average is given for `pars`,
+          an error occurs", {
   pars <- "ALLSKY_SFC_SW_DWN_00_GMT"
   temporal_average <- "DAILY"
   lonlat <- c(-179.5, -89.5)
